### 1.1.0 - 2025-07-14

*   [rmdepcheck-1.1.0.tar.gz](https://files.pythonhosted.org/packages/source/r/rmdepcheck/rmdepcheck-1.1.0.tar.gz)

1.  Add `--removes` mode to test removal rather than replacement of packages

### 1.0.2 - 2025-06-19

*   [rmdepcheck-1.0.2.tar.gz](https://files.pythonhosted.org/packages/source/r/rmdepcheck/rmdepcheck-1.0.2.tar.gz)

1.  Replace use of `sha256sum` command with hashlib calls

### 1.0.1 - 2025-06-19

*   [rmdepcheck-1.0.1.tar.gz](https://files.pythonhosted.org/packages/source/r/rmdepcheck/rmdepcheck-1.0.1.tar.gz)

1.  Re-arrange source tree to avoid including tests in wheel
2.  Some typing-related fixes

### 1.0.0 - 2025-06-19

*   [rmdepcheck-1.0.0.tar.gz](https://files.pythonhosted.org/packages/source/r/rmdepcheck/rmdepcheck-1.0.0.tar.gz)

1.  First release of rmdepcheck
